%define uname   CGAL

%define soname  12
%define libname %mklibname %{name} %{soname}
%define devname %mklibname %{name} -d

Name:           cgal
Version:        4.9.1
Release:        %mkrel 1
Summary:        Computational Geometry Algorithms Library
Group:          System/Libraries
License:        LGPLv3+ and GPLv3+ and Boost
URL:            http://www.cgal.org
Source0:        https://github.com/CGAL/cgal/releases/download/releases%2F%{uname}-%{version}/%{uname}-%{version}.tar.xz
Source1:        README.Mageia

BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  gmp-devel
BuildRequires:  mpfr-devel
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(zlib)

%description
The goal of the CGAL Open Source Project is to provide easy access
to efficient and reliable geometric algorithms in the form of a C++
library. CGAL is used in various areas needing geometric computation,
such as: computer graphics, scientific visualization, computer aided
design and modeling, geographic information systems, molecular biology,
medical imaging, robotics and motion planning, mesh generation, numerical
methods... More on the projects using CGAL web page.

#----------------------------------------------------------------------------

%package -n     %{libname}
Group:          System/Libraries
Summary:        Computational Geometry Algorithms Library

%description -n %{libname}
%{desc}

%files -n       %{libname}
%doc AUTHORS LICENSE LICENSE.FREE_USE LICENSE.LGPL LICENSE.GPL CHANGES README.Mageia
%{_libdir}/lib%{uname}*.so.%{soname}{,.*}

#----------------------------------------------------------------------------

%package -n     %{devname}
Group:          Development/C++
Summary:        Development files and tools for CGAL applications
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Provides:       %{uname}-devel = %{version}-%{release}

%description -n %{devname}
This package provides the headers files and tools you may need to
develop applications using CGAL.

%files -n       %{devname}
%{_includedir}/%{uname}
%{_libdir}/lib%{uname}*.so
%{_libdir}/%{uname}
%dir %{_datadir}/%{uname}
%{_bindir}/%{name}*
%exclude %{_bindir}/%{name}_make_macosx_app
%{_mandir}/man1/%{name}_create_cmake_script.1*

#----------------------------------------------------------------------------

%package        demos-source
Group:          Documentation
Summary:        Examples and demos of CGAL algorithms
Requires:       %{devname} = %{version}-%{release}

%description    demos-source
This package provides the sources of examples and demos of CGAL algorithms.

%files          demos-source
%{_datadir}/%{uname}/demo
%{_datadir}/%{uname}/examples
%exclude %{_datadir}/%{uname}/*/*/skip_vcproj_auto_generation

#----------------------------------------------------------------------------

%prep
%setup -q -n %{uname}-%{version}

cp %{SOURCE1} .
sed -i -e 's/LIBNAME/%{libname}/g' -e 's/DEVNAME/%{devname}/g' README.Mageia

%build
%cmake -DCMAKE_BUILD_TYPE=Release \
       -DCGAL_INSTALL_LIB_DIR=%{_lib} \
       -DCGAL_INSTALL_DOC_DIR=
%make_build

%install
%make_install -C build

# Install demos and examples
mkdir -p %{buildroot}%{_datadir}/%{uname}
cp -a demo %{buildroot}%{_datadir}/%{uname}/demo
cp -a examples %{buildroot}%{_datadir}/%{uname}/examples


%changelog
* Thu Apr 20 2017 akien <akien> 4.9.1-1.mga6
+ Revision: 1096968
- Version 4.9.1

* Sat Oct 29 2016 akien <akien> 4.9-1.mga6
+ Revision: 1063911
- Version 4.9, major 12

* Thu Aug 11 2016 akien <akien> 4.8.1-1.mga6
+ Revision: 1045736
- Version 4.8.1

* Thu May 19 2016 akien <akien> 4.8-1.mga6
+ Revision: 1016968
- Version 4.8, uses Qt5

* Sat Dec 26 2015 daviddavid <daviddavid> 4.6.2-3.mga6
+ Revision: 915157
- rebuild for new boost 1.60.0

* Fri Sep 25 2015 daviddavid <daviddavid> 4.6.2-2.mga6
+ Revision: 883663
- rebuild for new boost 1.59.0

* Sat Aug 29 2015 daviddavid <daviddavid> 4.6.2-1.mga6
+ Revision: 870843
- new version: 4.6.2
- rebuild for new boost-1.58.0

* Wed Jun 24 2015 akien <akien> 4.6-1.mga6
+ Revision: 842258
- Increased soname major
- Version 4.6

* Wed Oct 15 2014 umeabot <umeabot> 4.4-4.mga5
+ Revision: 739526
- Second Mageia 5 Mass Rebuild

* Thu Sep 18 2014 umeabot <umeabot> 4.4-3.mga5
+ Revision: 693589
- Rebuild to fix library dependencies

* Tue Sep 16 2014 umeabot <umeabot> 4.4-2.mga5
+ Revision: 678354
- Mageia 5 Mass Rebuild

* Thu Jun 12 2014 akien <akien> 4.4-1.mga5
+ Revision: 635850
- Update description
- Package CGAL properly following the library policy of Mageia
- Adapt the README from Fedora to Mageia
- Rename CGAL to cgal as per our policy
- import source RPM from Fedora

